@@ -16,7 +16,7 @@ class DKConnection():
         if r.text == 'Credentials are invalid':
             raise Exception
         if "\n" in r.text or "\r" in r.text:
-            logger.error("Error: Platform returned invalid token." % (kitchen, recipe, variation))
+            logger.error("Error: Platform returned invalid token.")
         self.token = r.text
         self.headers =  {'content-type': 'application/json', 'authorization': 'Bearer ' + self.token}
 
@@ -67,8 +67,14 @@ class DKConnection():
                    'testresults': True, 'servingjson': True, "schedule": "now"}
         r = requests.post(url, headers=headers, data=json.dumps(payload))
         if "does not exist." in r.text:
-            raise Exception("Order run id %s not found." % order_run_id )
-        return DKOrder(json.loads(r.text))
+            logger.error("Order id %s not found." % order_id)
+            raise DKOrderNotFoundException 
+        try:
+            return DKOrder(json.loads(r.text))
+        except Exception as e:
+            logger.error(str(r.status_code))
+            logger.error(str(r.text))
+            raise e
 
     def OrderRunInfo(self, kitchen, order_run_id):
         url = "https://%s/v2/order/details/%s" % (self.hostname, kitchen)
